@@ -173,6 +173,8 @@ ppc_intervals_grouped <- function(y,
 
 #' @rdname PPC-intervals
 #' @export
+#' @param y_draw For ribbon plots only, a string specifying how to draw `y`. Can
+#'   be `"line"` (the default), `"points"`, or `"both"`.
 ppc_ribbon <- function(y,
                        yrep,
                        x = NULL,
@@ -180,7 +182,8 @@ ppc_ribbon <- function(y,
                        prob = 0.5,
                        prob_outer = 0.9,
                        alpha = 0.33,
-                       size = 0.25) {
+                       size = 0.25,
+                       y_draw = c("line", "points", "both")) {
   check_ignored_arguments(...)
 
   data <- ppc_intervals_data(
@@ -197,7 +200,8 @@ ppc_ribbon <- function(y,
     size = size,
     grouped = FALSE,
     style = "ribbon",
-    x_lab = label_x(x)
+    x_lab = label_x(x),
+    y_draw = y_draw
   )
 }
 
@@ -213,7 +217,8 @@ ppc_ribbon_grouped <- function(y,
                                prob = 0.5,
                                prob_outer = 0.9,
                                alpha = 0.33,
-                               size = 0.25) {
+                               size = 0.25,
+                               y_draw = c("line", "points", "both")) {
   check_ignored_arguments(...)
 
   data <- ppc_intervals_data(
@@ -234,7 +239,8 @@ ppc_ribbon_grouped <- function(y,
     size = size,
     grouped = TRUE,
     style = "ribbon",
-    x_lab = label_x(x)
+    x_lab = label_x(x),
+    y_draw = y_draw
   )
 }
 
@@ -319,9 +325,11 @@ label_x <- function(x) {
            size = 1,
            grouped = FALSE,
            style = c("intervals", "ribbon"),
-           x_lab = NULL) {
+           x_lab = NULL,
+           y_draw = c("line", "points", "both")) {
 
   style <- match.arg(style)
+  y_draw <- match.arg(y_draw)
 
   graph <- ggplot(
     data = data,
@@ -349,11 +357,22 @@ label_x <- function(x) {
         aes_(color = "yrep"),
         size = size/2
       ) +
-      geom_blank(aes_(fill = "y")) +
-      geom_line(
+      geom_blank(aes_(fill = "y"))
+
+    if (y_draw == "line" || y_draw == "both") {
+      graph <- graph + geom_line(
         aes_(y = ~ y_obs, color = "y"),
         size = 0.5
       )
+    }
+
+    if (y_draw == "points" || y_draw == "both") {
+      graph <- graph + geom_point(
+        mapping = aes_(y = ~ y_obs, color = "y", fill = "y"),
+        shape = 21,
+        size = 1.5
+      )
+    }
   } else {
     graph <- graph +
       geom_pointrange(
